@@ -4,8 +4,13 @@ from django.core.cache import cache
 from django.utils import translation
 from django.conf import settings
 import logging
+from ..import get_class_for_view
 
-from .. import SEO_CACHE_PREFIX, SEO_CACHE_TIMEOUT, SEO_USE_CACHE, get_model_for_view
+from ..settings import (
+    SEO_CACHE_PREFIX,
+    SEO_CACHE_TIMEOUT,
+    SEO_USE_CACHE,
+)
 
 from ..fields import (
     TitleTagField,
@@ -57,14 +62,14 @@ class MetadataNode(template.Node):
                 log.debug("Cache metadata hit for view %s" % view_name)
                 return metadata_html
 
-        seo_model = get_model_for_view(view_name)
+        seo_model = get_class_for_view(view_name)
         try:
             metadata = seo_model.objects.get(view_name=view_name)
             metadata_html = ""
             for field in metadata._meta.fields:
-                if not self._check_field_i18n(field) and isinstance(field,
-                                                               (TitleTagField, MetaTagField, KeywordsTagField,
-                                                                URLMetaTagField, ImageMetaTagField)):
+                if not self._check_field_i18n(field) and isinstance(
+                        field,
+                        (TitleTagField, MetaTagField, KeywordsTagField, URLMetaTagField, ImageMetaTagField)):
                     printed_tag = field.to_python(getattr(metadata, field.name)).print_tag()
                     if printed_tag and printed_tag != "":
                         metadata_html += printed_tag + "\n"
